@@ -2,7 +2,9 @@
 import os
 import sys
 import time
+import threading
 from argparse import ArgumentParser
+
 from watchdog.observers import Observer
 from watchdog.events import FileSystemEventHandler
 from pettifogger.utils.configuration import GlobalConfiguration, set_global_configuration
@@ -20,16 +22,22 @@ class WorkflowWatcher(FileSystemEventHandler):
     def __init__(self, *args, **kwargs):
         super().__init__(*args, **kwargs)
         self.watched = []
+        self._lock = threading.Lock()
+
+    def __release_lock_after_grace_period(self, grace):
+        time.sleep(grace)
+        self._lock.release()
 
     def add_to_watched(self, path):
         self.watched.append(path)
 
     def on_modified(self, event):
         super().on_modified(event)
-        print(event.src_path)
-        if event.src_path.endswith("~") or event.src_path not in self.watched:
+        if event.src_path.endswith("~") or event.src_path not in self.watched or self._lock.locked():
             return
-
+        self._lock.acquire()
+        release = threading.Thread(target=self.__release_lock_after_grace_period, args=(2,))
+        release.start()
 
         if event.is_directory:
             files = os.listdir(event.src_path)
@@ -37,12 +45,12 @@ class WorkflowWatcher(FileSystemEventHandler):
             files = [event.src_path]
         files = list(map(lambda x: os.path.join(event.src_path, x), files))
         filtered_files = list(filter(lambda x: os.path.exists(x) and not x.endswith("~"), files))
-        print(event.src_path, event.is_directory, files, filtered_files)
         results = validate_files(filtered_files)
 
         if not all(results):
-            print(f"Workflow validation failed, please check the logs", file=sys.stderr)
+            print(f"\n\nWorkflow validation failed, please check the logs", file=sys.stderr)
 
+        print("\n-----------------------------------------------------------------------------------\n")
 
 def validate_files(files):
     results = []
@@ -72,7 +80,7 @@ def main():
     parser.add_argument("--suppress-suspicions", action="store_true", help="Suppresses the suspicion output")
     parser.add_argument("--fail-on-suspicions", action="store_true", help="Suspicions fail the validation")
     parser.add_argument("--no-fail-on-error", action="store_true", help="Errors will not fail the validation")
-    parser.add_argument("--watch", action="store_true", help="Errors will not fail the validation")
+    parser.add_argument("--watch", action="store_true", help="Watch the file or workflow subdirectories detected automatically")
     args = parser.parse_args()
 
     if args.version:
@@ -104,7 +112,7 @@ def main():
 
     if not args.watch:
         if not all(results):
-            print(f"Workflow validation failed, please check the logs", file=sys.stderr)
+            print(f"\n\nWorkflow validation failed, please check the logs", file=sys.stderr)
             if args.no_fail_on_error:
                 exit(0)
             exit(1)
