@@ -12,10 +12,11 @@ class State:
 
 
 class StatefulLogger:
-    def __init__(self, indent=0, level=0, state=State()):
+
+    def __init__(self, indent=0, level=0, state=None):
         self.indent = indent
         self.level = level
-        self.state = state
+        self.state = State() if state is None else state
 
     def __log(self, msg, color, *, level=None):
         if level is None:
@@ -23,14 +24,17 @@ class StatefulLogger:
         terminal_size = shutil.get_terminal_size((120, 20))
         width = max(int(terminal_size.columns / 2), 120)  # Because.... Hervantavakiot?
         indent = " " * self.indent * level
-        wrapper = textwrap.TextWrapper(width=width, initial_indent=indent, subsequent_indent=indent)
+        sub_indent = " " * self.indent * (level + 1)
+        wrapper = textwrap.TextWrapper(width=width,
+                                       initial_indent=indent,
+                                       subsequent_indent=sub_indent)
 
         msg = wrapper.fill(color + msg + Style.RESET_ALL)
         print(msg)
 
     def info(self, *args):
         msg = ", ".join(args)
-        self.__log(msg, Fore.LIGHTBLUE_EX)
+        self.__log(msg, Fore.LIGHTCYAN_EX)
 
     def warn(self, *args, source_id=None):
         if source_id is None:
@@ -67,7 +71,7 @@ SUMMARY ({kwargs.get('filename', '')})
 
         print(f"SUSPICIONS ({sum([len(v) for v in self.state.suspicions.values()])}):\n")
         for logger_id, msgs in self.state.suspicions.items():
-            self.__log(logger_id + ":", Fore.LIGHTYELLOW_EX, level=0)
+            self.__log(logger_id + ":", Fore.LIGHTCYAN_EX, level=0)
             for msg in msgs:
                 self.__log("\u2600 " + msg, Fore.LIGHTYELLOW_EX, level=1)
 
@@ -75,7 +79,7 @@ SUMMARY ({kwargs.get('filename', '')})
 
         print(f"ERRORS ({ sum([len(v) for v in self.state.errors.values()]) }):\n")
         for logger_id, msgs in self.state.errors.items():
-            self.__log(logger_id + ":", Fore.LIGHTRED_EX, level=0)
+            self.__log(logger_id + ":", Fore.LIGHTCYAN_EX, level=0)
             for msg in msgs:
                 self.__log("\u2600 " + msg, Fore.LIGHTRED_EX, level=1)
 
